/**
 * Beispielsklasse zur Extraktion von GML-Punkten.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import java.sql.*;
import oracle.sql.STRUCT;
import oracle.spatial.geometry.JGeometry;

public class ProcessGML {

	/**
	 * Die Datenbankverbindung.
	 */
	static private Connection db;
	/**
	 * Einfge-Anweisung.
	 */
	static private PreparedStatement insert;

/**
 * Initialisierung der Klasse.
 */	
static {
	try {
		// Verbindung zur Datenbank aufbauen
		db = DriverManager.getConnection("jdbc:default:connection:");
		// Insert vorbereiten
		String sql = "INSERT INTO POIPositionen (gkz,name,pos) VALUES (?,?,?)";
		insert = db.prepareStatement(sql);
	}
	catch (Exception ex) {
		System.err.println("Fehler: "+ex);
	}
}
/**
 * Einfgen der Koordinaten in die Tabelle "POIPositionen".
 */
public static void insertPos (int gkz, String name, String coords) {
	try {
		// aus coords eine JGeometry erzeugen
		coords = coords.trim();
		double x = Double.parseDouble(coords.substring(0,coords.indexOf(' ')));
		double y = Double.parseDouble(coords.substring(coords.lastIndexOf(' ')+1));
		JGeometry point = new JGeometry(x,y, 8307);   // 10.2: 4326
		// Datensatz einfgen
		insert.setInt(1,gkz);
		insert.setString(2,name);
		STRUCT struct = JGeometry.store(point,db);
		insert.setObject (3,struct);
		insert.executeUpdate();
	} // try
	catch (Exception ex) {
		System.out.print("Fehler: "+ex);
	}
}
}
