/**
 * Beispielsprogramm zur Demonstration des Einlesens ber oracle.sdoapi.geom.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import static gdbutil.ConnectionParameters.*;

import java.sql.*;

import oracle.sql.STRUCT;
import oracle.sdoapi.OraSpatialManager;
import oracle.sdoapi.adapter.GeometryAdapter;
import oracle.sdoapi.adapter.GeometryInputTypeNotSupportedException;
import oracle.sdoapi.geom.*;

public class SdoapiReadExample {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		Class.forName("oracle.jdbc.driver.OracleDriver");
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// GeometryAdapter holen
		GeometryAdapter adapter = OraSpatialManager.getGeometryAdapter
			("SDO","8.1.6",STRUCT.class,null,null,db);
		if (adapter == null) {
			db.close();
			throw new ClassNotFoundException("Kein GeometryAdapter!");
		}
			
		// Anfrage ausfhren
		Statement statement = db.createStatement();
		String sql = "SELECT * FROM Gemeinden WHERE gkz = 3403000";
		ResultSet result = statement.executeQuery(sql);
		if (result.next()) {
			System.out.print(result.getString("name") + " - ");
			Point centrum = (Point)adapter.importGeometry(result.getObject("centrum"));
			System.out.println(centrum.getX()+" / "+centrum.getY());
			Polygon pol = (Polygon)adapter.importGeometry(result.getObject("gebiet"));
			CurveString outerRing = pol.getExteriorRing();
			System.out.println("#Eckpunkte: "+outerRing.getNumPoints());
		}
		result.close();
		statement.close();

		// Verbindung schlieen
		db.close();
	} // try

	// Fehlerbehandlung, falls die Klasse nicht gefunden wird
	catch (ClassNotFoundException ex) {
		System.err.println("SdoapiReadExample.main: "+ex);
	}
	// Fehlerbehandlung beim Datenbankzugriff
	catch (SQLException ex) {
		System.err.println("SdoapiReadExample.main: "+ex);
	}
	// Fehlerbehandlung bei der Umwandlung
	catch (GeometryInputTypeNotSupportedException ex) {
		System.err.println("SdoapiReadExample.main: "+ex);
	}
	catch (InvalidGeometryException ex) {
		System.err.println("SdoapiReadExample.main: "+ex);
	}
}

}
