import static gdbutil.ConnectionParameters.*;

import java.io.*;      // Import der Ein-/Ausgabe-Klassen
import java.net.URL;   // Import der URL-Klasse
import java.sql.*;     // Import der JDBC-Klassen

/**
 * Klasse, um ein WMS-Rasterbild in einem Oracle-BLOB zu speichern.
 * Ausfhrung bentigt ojdbc14.jar.
 * 
 * @author: Thomas Brinkhoff, http://www.geodbs.de/
 */
public class StoreRasterInBlob {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		Class.forName("oracle.jdbc.driver.OracleDriver");
		String dbUrl = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(dbUrl, DBUSER, DBPASSWORD);

		// Datensatz einfgen
		db.setAutoCommit(false);		// Auto-Commit-Modus aus
		Statement stmt = db.createStatement();
		stmt.executeUpdate("INSERT INTO Rasterkarten (id,name,karte) VALUES (1,'C:\\Temp\\OldenburgerLand.png',empty_blob())");
		// BLOB holen
		ResultSet res = stmt.executeQuery("SELECT karte FROM Rasterkarten WHERE id = 1");
		if (! res.next())
			throw new SQLException ("BLOB nicht gefunden!");
		Blob blob = res.getBlob(1);

		// Datenstrme ffnen
		URL url = new URL("http://www.mapserver.niedersachsen.de/freezoneogc/mapserverogc?VERSION=1.1.1&"+
				"REQUEST=GetMap&LAYERS=DUEKN500&STYLES=&SRS=EPSG:31467&"+
				"BBOX=3430000,5870000,3470000,5910000&WIDTH=600&HEIGHT=600&FORMAT=png");
		InputStream urlStream = url.openStream();
		//OutputStream blobStream = ((oracle.sql.BLOB)blob).getBinaryOutputStream();
		OutputStream blobStream = blob.setBinaryStream(1);
		// Daten kopieren
		byte[] buffer = new byte[1024];
		int size = urlStream.read(buffer);
		while (size != -1) {
			blobStream.write (buffer, 0,size);
			size = urlStream.read(buffer);
		}
		// Datenstrme schlieen
		urlStream.close();
		blobStream.close();

		/* Datei-Variante mit setBytes
		File file = new File("C:\\Temp\\karte.gif");
 		FileInputStream dateiStream = new FileInputStream(file);
 		byte[] buffer = new byte[(int)file()];
		dateiStream.read(buffer);
		blob.setBytes(1,buffer);
		//((oracle.sql.BLOB)blob).putBytes(1,buffer);  // Oracle 9
		dateiStream.close(); */

		// Transaktion abschlieen
		db.commit();  
		// Anweisung und Verbindung schlieen
		stmt.close();
		db.close();
	}
	// Fehler behandeln
	catch (Exception ex) {
		System.err.println("StoreRasterInBlob.main: "+ex);
	}
}
}
