package gdbutil;

/**
 * Class replacing DataInputStream without throwing exceptions.
 * @version	1.0	29.09.00
 * @author: Thomas Brinkhoff
 */
public class BufferedInputStreamReader {

	/**
	 * Data input stream of the standard input.
	 */
	private java.io.BufferedReader in = new java.io.BufferedReader(new java.io.InputStreamReader(System.in));
	/**
	 * An error occurred?
	 */
	private boolean error = false;

/**
 * Returns the value of the error flag.
 * @return the error flag
 */
public boolean errorOccurred() {
	return error;
}
/**
 * Reads a signed 8-bit value from the input stream.
 * @return the byte value
 */
public byte readByte() {
	error = false;
	try {
		String s = readLine();
		return Byte.parseByte(s);
	}
	catch (Exception e) {
		error = true;
		return (byte)0;
	}
}
/**
 * Reads a Unicode char value from the input stream.
 * @return the char value
 */
public char readChar() {
	error = false;
	try {
		return (char) in.read();
	}
	catch (Exception e) {
		error = true;
		return ' ';
	}
}
/**
 * Reads a double value from the input stream.
 * @return the double value
 */
public double readDouble() {
	error = false;
	try {
		String s = readLine();
		return Double.parseDouble(s);
	}
	catch (Exception e) {
		error = true;
		return 0;
	}
}
/**
 * Reads a float value from the input stream.
 * @return the float value
 */
public float readFloat() {
	error = false;
	try {
		String s = readLine();
		return Float.parseFloat(s);
	}
	catch (Exception e) {
		error = true;
		return 0;
	}
}
/**
 * Reads four input bytes and returns an int value.
 * @return the int value
 */
public int readInt() {
	error = false;
	try {
		String s = readLine();
		return Integer.parseInt(s);
	}
	catch (Exception e) {
		error = true;
		return 0;
	}
}
/**
 * Reads the next line of text from the input stream.
 * @return the string
 */
public String readLine() {
	error = false;
	try {
		return in.readLine();
	}
	catch (Exception e) {
		error = true;
		return "";
	}
}
/**
 * Reads eight input bytes and returns a long value.
 * @return the long value
 */
public long readLong() {
	error = false;
	try {
		String s = readLine();
		return Long.parseLong(s);
	}
	catch (Exception e) {
		error = true;
		return 0;
	}
}
/**
 * Reads two input bytes and returns a short value.
 * @return the short value
 */
public short readShort() {
	error = false;
	try {
		String s = readLine();
		return Short.parseShort(s);
	}
	catch (Exception e) {
		error = true;
		return (short)0;
	}
}
}
